elikopy package
===============

Submodules
----------

elikopy.core module
-------------------

.. automodule:: elikopy.core
   :members:
   :undoc-members:
   :show-inheritance:

elikopy.individual\_subject\_processing module
----------------------------------------------

.. automodule:: elikopy.individual_subject_processing
   :members:
   :undoc-members:
   :show-inheritance:

elikopy.utils module
--------------------

.. automodule:: elikopy.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: elikopy
   :members:
   :undoc-members:
   :show-inheritance:
